---
name: Bug report
about: Report unexpected behavior, a crash, or incorrect results

---

**Describe the bug**
A clear and concise description of what the bug is.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - fastnumbers version: 
 - Python Version: [e.g. 3.6]
 - OS [e.g. Windows, Fedora]
 - Compiler (if known): [e.g. gcc]

**To Reproduce**
Include a Minimum, Complete, Verifiable Example. If there is a traceback (or error message), **please** include the *entire* traceback (or error message), even if you think it is too big.

See https://stackoverflow.com/help/mcve for an explanation.
